package jp.gihyo.spring.mvc

import com.fasterxml.jackson.databind.PropertyNamingStrategy
import org.springframework.beans.factory.config.PropertyPlaceholderConfigurer
import org.springframework.boot.Banner
import org.springframework.boot.autoconfigure.SpringBootApplication
import org.springframework.boot.runApplication
import org.springframework.context.support.PropertySourcesPlaceholderConfigurer
import org.springframework.context.support.beans
import org.springframework.http.converter.json.Jackson2ObjectMapperBuilder

@SpringBootApplication
// 01 Kotlin と Spring Framework
// 02 all-open による Kotlin のクラス属性変更
class Application

fun main(args: Array<String>) {
    // 01 Kotlin と Spring Framework
    // 03 Kotlin DSL の導入
    // 01 runApplication
    runApplication<Application>(*args) {
        addInitializers(
            // 01 Kotlin と Spring Framework
            // 03 Kotlin DSL の導入
            // 02 Bean 定義
            beans {
                // 01 Kotlin と Spring Framework
                // 05 プロパティ値インジェクションのカスタマイズ
                bean {
                    PropertySourcesPlaceholderConfigurer()
                        .apply {
                            setPlaceholderPrefix("%{")
                        }
                }
                bean {
                    Jackson2ObjectMapperBuilder()
                        .propertyNamingStrategy(
                            PropertyNamingStrategy
                                .SNAKE_CASE
                        )
                }
            }
        )

        setBannerMode(Banner.Mode.OFF)
    }
}