package jp.gihyo.spring.mvc

import org.springframework.stereotype.Controller
import org.springframework.ui.Model
import org.springframework.ui.set
import org.springframework.web.bind.annotation.GetMapping
import org.springframework.web.bind.annotation.RequestMapping
import org.springframework.web.bind.annotation.RequestParam
import org.springframework.web.bind.annotation.ResponseBody


@Controller
@RequestMapping("kotlin")
class KotlinController(
    // 01 Kotlin と Spring Framework
    // 04 Spring の null安全対応
    // 02 Bean インジェクション
    private val sampleConfiguration: SampleConfiguration
) {
    @GetMapping("hello")
    @ResponseBody
    fun hello(
        // 01 Kotlin と Spring Framework
        // 04 Spring の null安全対応
        // 01 リクエストパラメータ
        @RequestParam name: String,
        @RequestParam voice: String?
    ): String {
        return (voice ?: "Hello") + " " + name
    }

    // 01 Kotlin と Spring Framework
    // 04 Spring の null安全対応
    // 03 Model のキーアクセス
    @GetMapping
    fun index(model: Model): String {
        model["key"] = "value"
        return "index"
    }

    @GetMapping("sample")
    @ResponseBody
    fun sample(): String {
        return sampleConfiguration.value
    }
}